@@ -1,4 +1,4 @@
-from qosic.utils import is_allowed_string, get_random_string, ALLOWED_STRING_CHARS
+from qosic.models import get_random_string, ALLOWED_STRING_CHARS
 
 
 def test_get_random_string():
@@ -6,8 +6,3 @@ def test_get_random_string():
     assert isinstance(random_string, str)
     for char in random_string:
         assert char in ALLOWED_STRING_CHARS
-
-
-def test_is_allowed_string():
-    random_string = get_random_string()
-    assert is_allowed_string(random_string)
